@@ -334,3 +334,17 @@ void PuntateMain::on_stream21_clicked()
     process.start("sh /opt/serviziopubblico/script/p21.sh");
     process.waitForFinished();
 }
+
+void PuntateMain::on_down22_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/d22.sh");
+    process.waitForFinished();
+}
+
+void PuntateMain::on_stream22_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/p22.sh");
+    process.waitForFinished();
+}
