@@ -104,6 +104,10 @@ private slots:
 
     void on_stream21_clicked();
 
+    void on_down22_clicked();
+
+    void on_stream22_clicked();
+
 private:
     Ui::PuntateMain *ui;
 };
